@@ -66,16 +66,21 @@ void usage(const Protocol& prot) {
   STD_cout << "micalc:  Performs basic mathematics with data sets" << STD_endl;
   STD_cout << "         File formats are automatically identified by their file extension." << STD_endl;
   STD_cout << "         For binary operations with two input files, the protocol of the first input file will be used for the output file." << STD_endl;
+  STD_cout << configInfo() << STD_endl;
+  STD_cout << STD_endl;
   STD_cout << "micalc can be used in one of the following modes:" << STD_endl;
   STD_cout << "  Binary operation with data sets and/or scalar numbers:" << STD_endl;
   STD_cout << "       micalc [-if1 <input-file1> | -in1 <input-number1>] -op <operation(+,-,*,/,min,max,lcorr,kcorr)> [-if2 <input-file2> | -in2 <input-number1>] -of <output-file>" << STD_endl;
   STD_cout << "  Accumulation/reduction of one data set:" << STD_endl;
   STD_cout << "       micalc -if <input-file> -op <operation(+,*,mean,median,stdev,min,max)>" << STD_endl;
   STD_cout << "  Transformation (magnitude, logarithm, ...) of one data set:" << STD_endl;
-  STD_cout << "       micalc -if <input-file> -op <operation(abs,log,exp,-,/,acos)> -of <output-file>" << STD_endl;
+  STD_cout << "       micalc -if <input-file> -op <operation(abs,sqrt,log,exp,-,/,acos)> -of <output-file>" << STD_endl;
   STD_cout << "  Statistics of one data set:" << STD_endl;
-  STD_cout << "       micalc -if <input-file> [-mean <time-mean-file>] [-stdev <time-stdev-file>] [-fluct <relative-time-stdev-file>] [-tcourse <average time course of all voxels>]"
-                      "[-hist <histogram> -histslots <numofslots> [-histmin <minval>] [-histmax <maxval>] [-rightstairs] [-histfract] [-loghist] [-histslotmap <file>]]" << STD_endl;
+  STD_cout << "       micalc -if <input-file>" << STD_endl;
+  STD_cout << "         [-mean <time-mean-file>] [-stdev <time-stdev-file>] [-fluct <relative-time-stdev-file>] [-tcourse <average time course of all voxels>]" << STD_endl;
+  STD_cout << "         [-hist <histogram> -histslots <numofslots> [-histmin <minval>] [-histmax <maxval>] [-rightstairs] [-histfract] [-loghist] [-histslotmap <file>]]" << STD_endl;
+  STD_cout << "         [-cog <center-of-gravity-file>]" << STD_endl;
+
   STD_cout << "Extra options:" << STD_endl;
   STD_cout << "\t-mask <Binary mask file: voxels with zeroes are discarded>" << STD_endl;
   STD_cout << "File read options:" << STD_endl;
@@ -171,6 +176,9 @@ int main(int argc, char* argv[]) {
   STD_string histfile;
   if(getCommandlineOption(argc,argv,"-hist",optval,ODIN_MAXCHAR)) histfile=optval;
 
+  STD_string cogfile;
+  if(getCommandlineOption(argc,argv,"-cog",optval,ODIN_MAXCHAR)) cogfile=optval;
+
   STD_string meanfile;
   STD_string fluctfile;
   STD_string stdevfile;
@@ -369,6 +377,7 @@ int main(int argc, char* argv[]) {
     ODINLOG(odinlog,infoLog) << "Calculating " << operation << " " << data1.shape() << " ..." << STD_endl;
     bool validop=false;
     if(operation=="abs")  {validop=true; result=fabs(data1);}
+    if(operation=="sqrt") {validop=true; result=sqrt(data1);}
     if(operation=="log")  {validop=true; result=where(Array<float,4>(data1)>0.0, Array<float,4>(log(data1)), float(0.0));}
     if(operation=="exp")  {validop=true; result=exp(data1);}
     if(operation=="-")    {validop=true; result=-data1;}
@@ -484,39 +493,65 @@ int main(int argc, char* argv[]) {
     }
 
 
-    if(meanfile!="" || fluctfile!="" || stdevfile!="" || tcoursefile!="") {
-      outshape=data1.shape();
-      ODINLOG(odinlog,infoLog) << "calculating mean, standard deviation and/or timecourse for shape " << outshape <<  " ..." << STD_endl;
+    if(meanfile!="" || fluctfile!="" || stdevfile!="" || tcoursefile!="" || cogfile!="") {
+      TinyVector<int,4> inshape=data1.shape();
+      outshape=inshape;
+      ODINLOG(odinlog,infoLog) << "calculating general statistics for shape " << outshape <<  " ..." << STD_endl;
       outshape(0)=1;
       Data<float,4> meanresult(outshape); meanresult=0.0;
       Data<float,4> fluctresult(outshape); fluctresult=0.0;
       Data<float,4> stdevresult(outshape); stdevresult=0.0;
       Data<float,1> tcourseresult(data1.extent(0)); tcourseresult=0.0;
-      int tcoursepts=0;
+
+      farray cogsum(inshape(0), 3);
+      fvector masssum(inshape(0));
+
+      int maskpoints=0;
       for(unsigned int i=0; i<meanresult.numElements(); i++) {
         TinyVector<int,4> index=meanresult.create_index(i);
-        if(!index(0)) { // only once for all repetitions
-          if( !(maskptr && maskdata(index)==0.0) ) {
-            statisticResult stats=statistics(data1(all,index(1),index(2),index(3)));
-            meanresult(index)= stats.mean;
-            fluctresult(index)=secureDivision(stats.stdev,stats.mean);
-            stdevresult(index)=stats.stdev;
-            tcourseresult(all)+=data1(all,index(1),index(2),index(3));
-            tcoursepts++;
-            ODINLOG(odinlog,normalDebug) << "mean/stdev(" << index << ")=" << stats.mean << "/" << stats.stdev << STD_endl;
+        if( !(maskptr && maskdata(index)==0.0) ) {
+          statisticResult stats=statistics(data1(all,index(1),index(2),index(3)));
+          meanresult(index)= stats.mean;
+          fluctresult(index)=secureDivision(stats.stdev,stats.mean);
+          stdevresult(index)=stats.stdev;
+          tcourseresult(all)+=data1(all,index(1),index(2),index(3));
+          ODINLOG(odinlog,normalDebug) << "mean/stdev(" << index << ")=" << stats.mean << "/" << stats.stdev << STD_endl;
+
+          for(int irep=0; irep<inshape(0); irep++) {
+            float mass=data1(irep,index(1),index(2),index(3));
+            masssum[irep]+=mass;
+            for(int idim=0; idim<3; idim++) {
+              cogsum(irep,idim)+=mass*index(1+idim);
+            }
           }
+
+          maskpoints++;
         }
       }
-      tcourseresult/=float(tcoursepts);
+      ODINLOG(odinlog,infoLog) << "maskpoints=" << maskpoints << STD_endl;
+      tcourseresult/=float(maskpoints);
 
       if(meanfile!="")  if(meanresult.autowrite(meanfile,wopts,&prot)<0) return -1;
       if(fluctfile!="") if(fluctresult.autowrite(fluctfile,wopts,&prot)<0) return -1;
       if(stdevfile!="") if(stdevresult.autowrite(stdevfile,wopts,&prot)<0) return -1;
       if(tcoursefile!="") if(tcourseresult.autowrite(tcoursefile,wopts,&prot)<0) return -1;
+
+      if(cogfile!="") {
+        STD_string cogstr;
+        for(int irep=0; irep<inshape(timeDim); irep++) {
+          cogstr+=ftos(cogsum(irep, 0)/masssum[irep])+" "+ftos(cogsum(irep, 1)/masssum[irep])+" "+ftos(cogsum(irep, 2)/masssum[irep])+"\n";
+        }
+        write(cogstr, cogfile);
+      }
+
+
     } else {
       STD_cout << statistics(data1,maskptr) << STD_endl;
     }
 //    STD_cout << "median = " << median(data1) << STD_endl;
+
+
+
   }
 
   return 0;
