@@ -51,6 +51,8 @@ void usage(const Protocol& prot) {
   STD_cout << "         File formats are automatically identified by their file extension." << STD_endl;
   STD_cout << "         It expects at least two filenames/directories (for the input and output file) at the end of the command line." << STD_endl;
   STD_cout << "         An exception is the option '-l' which requires only one filename/directory to list its content." << STD_endl;
+  STD_cout << configInfo() << STD_endl;
+  STD_cout << STD_endl;
   STD_cout << "Usage: miconv [options] <input-file> [<output-file>]" << STD_endl;
   STD_cout << "General options:" << STD_endl;
   STD_cout << mopts.get_cmdline_usage("\t");
