@@ -22,6 +22,8 @@
 
 void OdinView::usage() {
    STD_cout << "odin: Graphical user interface of ODIN" << STD_endl;
+   STD_cout << configInfo() << STD_endl;
+   STD_cout << STD_endl;
    STD_cout << "Usage: odin [options]" << STD_endl;
    STD_cout << "Options:" << STD_endl;
    STD_cout << "\t-c : Do not load configuration" << STD_endl;
@@ -279,7 +281,7 @@ bool OdinView::create_seqplot(bool for_simulation) {
 #ifdef STANDALONE_PLUGIN
   Log<OdinComp> odinlog("OdinView","create_seqplot");
 
-  if(seqplot) delete seqplot; seqplot=0;
+  if(seqplot) {delete seqplot; seqplot=0;}
 
   if(!switch_to_platform(standalone)) return false;
 
@@ -883,7 +885,7 @@ void OdinView::recalc_method() {
 
   if(!method.link()) return;
 
-  if(seqplot) delete seqplot; seqplot=0;
+  if(seqplot) {delete seqplot; seqplot=0;}
 
   if(!method->clear()) {
     ODINLOG(odinlog,errorLog) << "clear() failed" << STD_endl;
