@@ -331,9 +331,7 @@ class DataTest : public UnitTest {
     if(diff) {
       ODINLOG(odinlog,errorLog) << "convert_to/from_ptr failed, diff=" << diff << STD_endl;
       ODINLOG(odinlog,errorLog) << "testarray=" << testarray << STD_endl;
-      ODINLOG(odinlog,errorLog) << "cmplxarr=";
-      for(unsigned int i=0; i<cmplxarr.size(); i++) ODINLOG(odinlog,errorLog) << cmplxarr[i] << "\t";
-      ODINLOG(odinlog,errorLog) << STD_endl;
+      ODINLOG(odinlog,errorLog) << "cmplxarr=" << cmplxarr << STD_endl;
       ODINLOG(odinlog,errorLog) << "testarray2=" << testarray2 << STD_endl;
       return false;
     }
