@@ -2,7 +2,7 @@
                           data.h  -  description
                              -------------------
     begin                : Fri Apr 6 2001
-    copyright            : (C) 2000-2015 by Thies Jochimsen & Michael von Mengershausen
+    copyright            : (C) 2000-2019 by Thies Jochimsen & Michael von Mengershausen
     email                : thies@jochimsen.de  mengers@cns.mpg.de
  ***************************************************************************/
 
@@ -23,13 +23,23 @@
 #include <tjutils/config.h>
 #endif
 
+
+#include <tjutils/tjstd.h>
+#include <tjutils/tjcomplex.h>
 #include <tjutils/tjfeedback.h>
 
+
 #ifdef ODIN_DEBUG
 #define BZ_DEBUG
 #endif
 
 
+#ifdef BLITZ_REPLACEMENT
+
+#include <../replacements/blitz_replacement.h>
+
+
+#else
 
 
 #include <blitz/blitz.h> // include 1st to overwrite mutex defines
@@ -67,6 +77,9 @@
 #endif
 using namespace blitz;
 
+#endif // BLITZ_REPLACEMENT
+
+
 
 #include <tjutils/tjtypes.h>
 #include <tjutils/tjprofiler.h>
@@ -77,6 +90,9 @@ using namespace blitz;
 #include <odindata/fileio_opts.h>
 
 
+
+#ifndef BLITZ_REPLACEMENT
+
 // some additional macros for complex numbers
 BZ_DECLARE_FUNCTION_RET (float2real, STD_complex);
 BZ_DECLARE_FUNCTION_RET (float2imag, STD_complex);
@@ -97,6 +113,9 @@ BZ_DECLARE_FUNCTION (secureInv)
 BZ_DECLARE_ARRAY_ET_SCALAR_OPS(tjstd_complex)
 #endif
 
+#endif // BLITZ_REPLACEMENT
+
+
 
 /**
   * @addtogroup odindata
@@ -144,10 +163,10 @@ public:
   Data(int extent1, int extent2,int extent3) : Array<T,N_rank>(extent1,extent2,extent3), fmap(0)  {}
   Data(int extent1, int extent2,int extent3,int extent4) : Array<T,N_rank>(extent1,extent2,extent3,extent4), fmap(0)  {}
   Data(int extent1, int extent2,int extent3,int extent4,int extent5) : Array<T,N_rank>(extent1,extent2,extent3,extent4,extent5), fmap(0)  {}
-  Data(int extent1, int extent2,int extent3,int extent4,int extent5,int extent6) : Array<T,N_rank>(extent1,extent2,extent3,extent4,extent5,extent6), fmap(0)  {}
-  Data(int extent1, int extent2,int extent3,int extent4,int extent5,int extent6,int extent7) : Array<T,N_rank>(extent1,extent2,extent3,extent4,extent5,extent6,extent7), fmap(0)  {}
-  Data(int extent1, int extent2,int extent3,int extent4,int extent5,int extent6,int extent7,int extent8) : Array<T,N_rank>(extent1,extent2,extent3,extent4,extent5,extent6,extent7,extent8), fmap(0)  {}
-  Data(int extent1, int extent2,int extent3,int extent4,int extent5,int extent6,int extent7,int extent8,int extent9) : Array<T,N_rank>(extent1,extent2,extent3,extent4,extent5,extent6,extent7,extent8,extent9), fmap(0)  {}
+//  Data(int extent1, int extent2,int extent3,int extent4,int extent5,int extent6) : Array<T,N_rank>(extent1,extent2,extent3,extent4,extent5,extent6), fmap(0)  {}
+//  Data(int extent1, int extent2,int extent3,int extent4,int extent5,int extent6,int extent7) : Array<T,N_rank>(extent1,extent2,extent3,extent4,extent5,extent6,extent7), fmap(0)  {}
+//  Data(int extent1, int extent2,int extent3,int extent4,int extent5,int extent6,int extent7,int extent8) : Array<T,N_rank>(extent1,extent2,extent3,extent4,extent5,extent6,extent7,extent8), fmap(0)  {}
+//  Data(int extent1, int extent2,int extent3,int extent4,int extent5,int extent6,int extent7,int extent8,int extent9) : Array<T,N_rank>(extent1,extent2,extent3,extent4,extent5,extent6,extent7,extent8,extent9), fmap(0)  {}
 
 
 /**
@@ -175,11 +194,20 @@ public:
   */
   Data(const tjarray<tjvector<T>,T>& a) : fmap(0) { (*this)=a;}
 
+
+#ifdef BLITZ_REPLACEMENT
+/**
+  * Constructor from array of different rank (Blitz++ replacement)
+  */
+  template<int M_rank>
+  Data(const Array<T,M_rank>& a) : Array<T,N_rank>(a), fmap(0) {}
+#else
 /**
   * Constructor from expression template
   */
   template<class T_expr>
   Data(BZ_ETPARM(_bz_ArrayExpr<T_expr>) expr) : Array<T,N_rank>(expr), fmap(0) {}
+#endif
 
 
 /**
@@ -203,6 +231,17 @@ public:
   */
   Data<T,N_rank>& operator = (const T& val) {Array<T,N_rank>::operator=(val); return *this;}
 
+
+#ifdef BLITZ_REPLACEMENT
+/**
+  * Assignment operator from RectView (Blitz++ replacement)
+  */
+  template<int M_rank>
+  inline Data<T,N_rank>& operator = (const RectView<const Array<T,M_rank>&,T,M_rank>& rhs) {
+    Array<T,N_rank>::operator = (rhs);
+    return *this;
+  }
+#else
 /**
   * Assignment operator for expression templates
   */
@@ -211,6 +250,8 @@ public:
     Data<T,N_rank>::reference(Data<T,N_rank>(expr)); // forwarding to constructor
     return *this;
   }
+#endif
+
 
 /**
   * Assignment from an equivalent tjarray (\ref arrays). If rank of 'a' is smaller, extent will pe padded with 1 at front.
@@ -377,11 +418,15 @@ public:
   static Array<T,N_rank> defaultArray;
 
 
+
+ protected:
+  void detach_fmap(); // to be accessed by ComplexData
+
+
  private:
 
   void interpolate1dim(unsigned int dim, int newsize, float subpixel_shift);
 
-  void detach_fmap();
 
   FileMapHandle* fmap;
 
@@ -417,10 +462,10 @@ inline STD_ostream& operator << (STD_ostream& s,const Range&) { return s;}
 template<int N_rank>
 TinyVector<int,N_rank> index2extent(const TinyVector<int,N_rank>& shape, unsigned int index) {
   TinyVector<int,N_rank> result;
-  unsigned int temp=index;
+  unsigned int subindex=index;
   for(int i=N_rank-1;i>=0;i--){
-    result(i)=temp%shape(i);
-    temp=temp/shape(i);
+    result(i)=subindex%shape(i);
+    subindex/=shape(i);
   }
   return result;
 }
@@ -787,15 +832,13 @@ TinyVector<int, N_rank> Data<T,N_rank>::create_index(unsigned long index) const
 
 template<typename T,int N_rank>
 unsigned long Data<T,N_rank>::create_linear_index(const TinyVector<int, N_rank>& indexvec) const {
-  unsigned long totalIndex=0,subsize;
-  TinyVector<int, N_rank> nn(Array<T,N_rank>::extent());
-  for(unsigned long i=0;i<N_rank;i++) {
-    nn(i)=1;
-    subsize=product(nn);
-    if(!subsize) subsize=1;
-    totalIndex+=subsize*indexvec(i);
+  unsigned long result=0;
+  unsigned long subsize=1;
+  for(int i=N_rank-1;i>=0;i--) {
+    result+=subsize*indexvec(i);
+    subsize*=Array<T,N_rank>::extent(i);
   }
-  return totalIndex;
+  return result;
 }
 
 ////////////////////////////////////////////////////////////////////////////
@@ -931,6 +974,8 @@ T* Data<T,N_rank>::c_array() {
 
   bool need_copying=false;
 
+#ifndef BLITZ_REPLACEMENT
+
   // check storage order
   TinyVector<int,N_rank>ord=Array<T,N_rank>::ordering();
   for(int i=0; i<N_rank-1; i++) {
@@ -945,6 +990,8 @@ T* Data<T,N_rank>::c_array() {
   // check for slicing
   if(!Array<T,N_rank>::isStorageContiguous()) need_copying=true;
 
+#endif
+
   if(need_copying) {
     ODINLOG(odinlog,normalDebug) << "need_copying" << STD_endl;
     Data<T,N_rank> tmp(Array<T,N_rank>::shape());
