@@ -366,7 +366,7 @@ int FileIO::autoread(ProtocolDataMap& pdmap, const STD_string& filename, const F
     prot.seqpars.set_MatrixSize(readDirection,shape(readDim));
 
     // Adjust total duration of sequence, only if uninitialized
-    ODINLOG(odinlog,normalDebug) << "ExpDuration=" << prot.seqpars.get_ExpDuration() << STD_endl;
+    ODINLOG(odinlog,normalDebug) << "ExpDuration(TR)=" << prot.seqpars.get_ExpDuration() << STD_endl;
     prot.seqpars.set_ExpDuration(STD_max(prot.seqpars.get_ExpDuration(), shape(0)*prot.seqpars.get_RepetitionTime()/(60.0*1000.0)));
 
     // Set label of protocol to filename
@@ -511,10 +511,12 @@ int FileIO::read_dir(ProtocolDataMap& pdmap, const STD_string& dirname, const Fi
 
       // Iterate over protocol-data pairs
       for(ProtocolDataMap::const_iterator pdit=onepdmap.begin(); pdit!=onepdmap.end(); ++pdit) {
-        const Protocol& onefileprot=pdit->first;
+        Protocol onefileprotcopy(pdit->first);
         const Data<float,4>& onefiledata=pdit->second;
 
-        KeyImageMap& imgmap=oneimagemap[onefileprot]; // Get/insert key-image map for this protocol
+        onefileprotcopy.use_acqstart_during_comparison(opts.framesplit);
+
+        KeyImageMap& imgmap=oneimagemap[onefileprotcopy]; // Get/insert key-image map for this protocol
 
 
         // Check x- and y-size
@@ -531,14 +533,14 @@ int FileIO::read_dir(ProtocolDataMap& pdmap, const STD_string& dirname, const Fi
         }
 
 
-        STD_string dtype_prot=onefileprot.system.get_data_type();
+        STD_string dtype_prot=onefileprotcopy.system.get_data_type();
 
         // Insert repetitions and slices separately into map
         for(int irep=0; irep<onefiledata.extent(timeDim); irep++) {
           for(int islice=0; islice<onefiledata.extent(sliceDim); islice++) {
 
-            double acqstart=onefileprot.seqpars.get_AcquisitionStart()+double(irep)*onefileprot.seqpars.get_RepetitionTime();
-            double sliceloc=onefileprot.geometry.get_sliceOffsetVector()[islice];
+            double acqstart=onefileprotcopy.seqpars.get_AcquisitionStart()+double(irep)*onefileprotcopy.seqpars.get_RepetitionTime();
+            double sliceloc=onefileprotcopy.geometry.get_sliceOffsetVector()[islice];
             ODINLOG(odinlog,normalDebug) << "acqstart/sliceloc=" << acqstart << "/" << sliceloc << STD_endl;
             Data<float,2>& dataref=imgmap[ImageKey(acqstart,sliceloc,dirfilename,dtype_prot)];
             dataref.resize(onefiledata.extent(phaseDim),onefiledata.extent(readDim));
@@ -553,7 +555,7 @@ int FileIO::read_dir(ProtocolDataMap& pdmap, const STD_string& dirname, const Fi
     }
   } // end iterating over files
 
-  ODINLOG(odinlog,loglevel()) << "Found " << oneimagemap.size() << " protocol(s) while reading files:" << STD_endl;
+  ODINLOG(odinlog,loglevel()) << "Found " << oneimagemap.size() << " protocol(s)" << STD_endl;
 
   ODINLOG(odinlog,normalDebug) << "mem(read): " << Profiler::get_memory_usage() << STD_endl;
 
@@ -612,11 +614,11 @@ int FileIO::read_dir(ProtocolDataMap& pdmap, const STD_string& dirname, const Fi
     shape(sliceDim)=slice_offsets.size();
     int ndatasets=imgmap.size();
     shape(timeDim)=ndatasets/shape(sliceDim); // interpret remainder as time dimension
-    ODINLOG(odinlog,loglevel()) << "ndatasets/shape(" << protindex << ")=" << ndatasets << "/" << shape << STD_endl;
-
-    if(ndatasets!=(shape(timeDim)*shape(sliceDim))) {
-      ODINLOG(odinlog,errorLog) << "Size mismatch, ndatasets(" << ndatasets << ")!=nreps(" << shape(timeDim) << ")*nslices(" << shape(sliceDim) << ")" << STD_endl;
-      return -1;
+    int remainder=ndatasets%shape(sliceDim);
+    if(remainder) {
+      int missing=shape(sliceDim)-remainder;
+      shape(timeDim)++;
+      ODINLOG(odinlog,warningLog) << "Sparse data with " << missing << " slices missing, ndatasets(" << ndatasets << ")!=nrep(" << shape(timeDim) << ")*nslices(" << shape(sliceDim) << ")" << STD_endl;
     }
 
     // Insert slices into data according to their ordering
@@ -641,7 +643,9 @@ int FileIO::read_dir(ProtocolDataMap& pdmap, const STD_string& dirname, const Fi
     // set new acquisition start and duration
     prot.seqpars.set_AcquisitionStart(min_acqstart);
     ODINLOG(odinlog,normalDebug) << "min_acqstart: " << min_acqstart << " max_acqstart: " << max_acqstart << " dur: "<< max_acqstart - min_acqstart+ prot.seqpars.get_RepetitionTime()/1000 << STD_endl;
-    prot.seqpars.set_ExpDuration( (max_acqstart - min_acqstart+ prot.seqpars.get_RepetitionTime()/1000 ) /60.0);
+    double expdur=(max_acqstart - min_acqstart+ prot.seqpars.get_RepetitionTime()/1000 ) /60.0;
+    ODINLOG(odinlog,normalDebug) << "ExpDuration(acqstart)=" << expdur << STD_endl;
+    prot.seqpars.set_ExpDuration(expdur);
 
     unsigned int nslices=shape(sliceDim);
 
@@ -719,6 +723,9 @@ int FileIO::autowrite(const ProtocolDataMap& pdmap, const STD_string& filename,
   opts_copy.split=false;
 
 
+  // TODO: check and correct protocol and data for consistency (nrep, nslices, ny, nx)
+
+
   ODINLOG(odinlog,loglevel()) << "Writing format " << ff->description() << STD_endl;
   int result=0;
   if(opts.split) {
@@ -860,6 +867,68 @@ class FileIOTest : public UnitTest {
       }
     }
 
+
+    // Testing write and read of multi-dataset DICOM data
+    FileIO::ProtocolDataMap pdmapout;
+    Protocol prot1;
+    Protocol prot2;
+
+    prot1.seqpars.set_AcquisitionStart(12.0);
+    prot1.seqpars.set_RepetitionTime(10.0);
+    prot1.seqpars.set_NumOfRepetitions(7);
+    prot1.geometry.set_nSlices(3);
+    prot1.study.set_Series("series11",11);
+
+    prot2.seqpars.set_AcquisitionStart(5423.0);
+    prot2.seqpars.set_RepetitionTime(50.0);
+    prot2.seqpars.set_NumOfRepetitions(4);
+    prot2.geometry.set_nSlices(9);
+    prot2.study.set_Series("series22",22);
+
+
+    Data<float,4> outdata1(prot1.seqpars.get_NumOfRepetitions(),prot1.geometry.get_nSlices(),56,78); outdata1=111.1;
+    Data<float,4> outdata2(prot2.seqpars.get_NumOfRepetitions(),prot2.geometry.get_nSlices(),64,96); outdata2=222.2;
+
+    pdmapout[prot1].reference(outdata1);
+    pdmapout[prot2].reference(outdata2);
+
+    FileWriteOpts writeopts;
+    writeopts.format="dcm";
+
+    LDRfileName writefname=tempfile();
+    ODINLOG(odinlog,normalDebug) << "writefname(dcm)=" << writefname << STD_endl;
+
+    if(FileIO::autowrite(pdmapout, writefname, writeopts)<0) return false;
+
+
+    FileIO::ProtocolDataMap pdmapin;
+    FileReadOpts readopts;
+    readopts.format="dcm";
+    STD_string readfname=writefname.get_dirname()+SEPARATOR_STR+writefname.get_basename_nosuffix()+STD_string("_dcm");
+    ODINLOG(odinlog,normalDebug) << "readfname(dcm)=" << readfname << STD_endl;
+
+    Protocol dummy_protocol_template;
+    if(FileIO::autoread(pdmapin, readfname, readopts, dummy_protocol_template)<0) return false;
+
+    if(pdmapout.size()!=pdmapin.size()) {
+      ODINLOG(odinlog,errorLog) << "pdmap size mismatch, readfname=" << readfname << ", pdmapout(" << pdmapout.size() << ")!=pdmapin(" << pdmapin.size() << ")" << STD_endl;
+      return false;
+    }
+
+    FileIO::ProtocolDataMap::const_iterator pdit=pdmapin.begin();
+    Data<float,4> indata1(pdit->second);
+    if(indata1.shape() != outdata1.shape()) {
+      ODINLOG(odinlog,errorLog) << "data1 shape mismatch, readfname=" << readfname << STD_endl;
+      return false;
+    }
+
+    ++pdit;
+    Data<float,4> indata2(pdit->second);
+    if(indata2.shape() != outdata2.shape()) {
+      ODINLOG(odinlog,errorLog) << "data2 shape mismatch, readfname=" << readfname << STD_endl;
+      return false;
+    }
+
     return true;
   }
 };
