@@ -103,6 +103,12 @@ bool check_dict(const char* func) {
   Log<FileIO> odinlog("DicomFormat",func);
   if (!dcmDataDict.isDictionaryLoaded()) {
     ODINLOG(odinlog,errorLog) << "No data dictionary loaded, check environment variable " << DCM_DICT_ENVIRONMENT_VARIABLE << STD_endl;
+    svector dirtoks=tokens(DCM_DICT_DEFAULT_PATH, ':');
+    for(unsigned int itok=0; itok<dirtoks.size(); itok++) {
+      if(filesize(dirtoks[itok].c_str())<0) {
+        ODINLOG(odinlog,errorLog) << "Dictionary file "<< dirtoks[itok] << " of the current dcmtk installation does not exist, please check local dcmtk configuration" << STD_endl;
+      }
+    }
     return true;
   }
   return false;
@@ -169,12 +175,15 @@ template<typename BASE,typename DST> DST endian(const BASE *b){
 svector fetch_from_MR_CSA_Header(DcmElement* csaHeader, STD_string label){
   Log<FileIO> odinlog("DicomFormat","fetch_from_MR_CSA_Header");
 
-  ODINLOG(odinlog,normalDebug) << "csaHeader->getLength()=" << csaHeader->getLength() << STD_endl;
-
   svector ret;
+
+  unsigned int csalength=csaHeader->getLength();
+  ODINLOG(odinlog,normalDebug) << "csaHeader->getLength()=" << csalength << STD_endl;
+  if(!csalength) return ret;
+
   Uint8 *array;
   csaHeader->getUint8Array(array);
-  for(STD_string::size_type pos=0;pos<=csaHeader->getLength();){
+  for(STD_string::size_type pos=0;pos<=csalength;){
     STD_string dummy((char*)array+pos);
     STD_string::size_type found=dummy.find(label);
     if(found==STD_string::npos) {
@@ -202,7 +211,7 @@ svector fetch_from_MR_CSA_Header(DcmElement* csaHeader, STD_string label){
           const unsigned s=ret.size();ret.resize(s+1);
           ret[s]=STD_string((char*)array+pos);//store the text if the is some
           pos+=((len+sizeof(Sint32)-1)/sizeof(Sint32))*sizeof(Sint32);//increment pos by len aligned to sizeof(Sint32)
-          if(pos>csaHeader->getLength()) { // integrity check
+          if(pos>csalength) { // integrity check
              ODINLOG(odinlog,normalDebug) << "pos out of bounds" << STD_endl;
              break;
           }
@@ -255,6 +264,8 @@ struct DicomFormat : public FileFormat {
   int read(Data<float,4>& data, const STD_string& filename, const FileReadOpts& opts, Protocol& prot) {
     Log<FileIO> odinlog("DicomFormat","read");
 
+    OFString valstr;
+
     ODINLOG(odinlog,normalDebug) << "filename=" << filename << STD_endl;
 
     const char* func="DicomFormat::read";
@@ -280,6 +291,29 @@ struct DicomFormat : public FileFormat {
     }
 
 
+    // The meta-info stuff not provided by dcmtk
+    DcmMetaInfo* metainfo=fileformat.getMetaInfo();
+
+
+    STD_string syntax;
+    if(!check_status(func,"TransferSyntaxUID",metainfo->findAndGetOFStringArray(DCM_TransferSyntaxUID, valstr),warning)) syntax=valstr.c_str();
+    ODINLOG(odinlog,normalDebug) << "syntax=" << syntax << STD_endl;
+    if(syntax==UID_JPEG2000LosslessOnlyTransferSyntax || syntax==UID_JPEG2000TransferSyntax) {
+      ODINLOG(odinlog,errorLog) << "Transfer syntax not supported in free version of dcmtk" << STD_endl;
+      return -1;
+    }
+
+
+/*  change representation (does not work)
+    if(syntax==UID_JPEGProcess14SV1TransferSyntax) {
+      if(!dset->chooseRepresentation(EXS_LittleEndianExplicit, NULL).good()) {
+        ODINLOG(odinlog,errorLog) << "Cannot change representation" << STD_endl;
+        return -1;
+      }
+    }
+*/
+
+
     DcmElement* csaHeader=0;
     if(dset->findAndGetElement(DcmTagKey(0x0029,0x1010),csaHeader).good()) {
       ODINLOG(odinlog,normalDebug) << "found Siemens-specific CSA Header" << STD_endl;
@@ -363,7 +397,6 @@ struct DicomFormat : public FileFormat {
     shape(3)=img.getWidth();
     ODINLOG(odinlog,normalDebug) << "shape=" << shape << STD_endl;
 
-    OFString valstr;
 
     STD_string image_type;
     if(!check_status(func,"ImageType",dset->findAndGetOFStringArray(DCM_ImageType, valstr),warning)) image_type=valstr.c_str();
@@ -462,12 +495,12 @@ struct DicomFormat : public FileFormat {
       default: ODINLOG(odinlog,errorLog) <<  "pixel representation not supportet"<< STD_endl;
     }
 
-    #ifdef ODIN_DEBUG
+#ifdef ODIN_DEBUG
     double min,max;
     img.getMinMaxValues(min,max);
     ODINLOG(odinlog,normalDebug) << "image range is " << min << " - " << max << STD_endl;
     ODINLOG(odinlog,normalDebug) << "datatype set to " << prot.system.get_data_type() << STD_endl;
-    #endif //ODIN_DEBUG
+#endif //ODIN_DEBUG
 
     // rescale data, if necessary
     float intercept=0;
@@ -724,9 +757,11 @@ struct DicomFormat : public FileFormat {
     // Timestamp temporal sorting of multi-file DICOMs
     prot.seqpars.set_AcquisitionStart(-1.0); // inidicates no useful value
     if(dset->findAndGetOFString(DCM_FrameReferenceTime, valstr).good()){ // for dynamic PET data
+      ODINLOG(odinlog,normalDebug) << "Using AcquisitionStart=FrameReferenceTime=" << valstr << STD_endl;
       prot.seqpars.set_AcquisitionStart(atof(valstr.c_str()));
     } else {
       if(dset->findAndGetOFString(DCM_AcquisitionTime, valstr).good()){// Try timestamp field first
+        ODINLOG(odinlog,normalDebug) << "Using AcquisitionStart=AcquisitionTime=" << valstr << STD_endl;
         LONGEST_INT sec, sec_series;
         double fract, fract_series;
         timestr2seconds(valstr, sec, fract);
@@ -738,6 +773,7 @@ struct DicomFormat : public FileFormat {
 
       } else {
         if(dset->findAndGetOFString(DCM_InstanceNumber, valstr).good()) { // fallback
+          ODINLOG(odinlog,normalDebug) << "Using AcquisitionStart=InstanceNumber=" << valstr << STD_endl;
           prot.seqpars.set_AcquisitionStart(atof(valstr.c_str()));
         }
       }
@@ -790,9 +826,18 @@ struct DicomFormat : public FileFormat {
     unsigned int index=0;
     for(FileIO::ProtocolDataMap::const_iterator pdit=pdmap.begin(); pdit!=pdmap.end(); ++pdit) {
 
-      Protocol prot(pdit->first); // writable copy to adjust FOV
+      Protocol prot(pdit->first); // writable copy to adjust FOV and geometry mode
       const Data<float,4>& data=pdit->second;
 
+      if(prot.geometry.get_Mode()==voxel_3d) {
+        ODINLOG(odinlog,normalDebug) << "Forcing slicepack mode" << STD_endl;
+        float slicespacing=secureDivision(prot.geometry.get_FOV(sliceDirection), data.extent(sliceDim));
+        prot.geometry.set_Mode(slicepack);
+        prot.geometry.set_nSlices(data.extent(sliceDim));
+        prot.geometry.set_sliceDistance(slicespacing);
+        prot.geometry.set_sliceThickness(slicespacing);
+      }
+
       DcmFileFormat fileformat;
 
       // The meta-info stuff not provided by dcmtk
@@ -903,21 +948,21 @@ struct DicomFormat : public FileFormat {
 
 
 
-      int xsize=data.extent(3);
-      int ysize=data.extent(2);
+      int xsize=data.extent(readDim);
+      int ysize=data.extent(phaseDim);
       if(opts.dialect=="siemens") {
         // Siemens screws up with some non-quadratic image sizes, so we will use next-power-of-2-sized quadratic images
-        int quadsize = 1 << (int)(ceil( log(double(STD_max(data.extent(2),data.extent(3))))/ log(2.0)));
+        int quadsize = 1 << (int)(ceil( log(double(STD_max(data.extent(phaseDim),data.extent(readDim))))/ log(2.0)));
         ODINLOG(odinlog,normalDebug) << "Fixing matrix size for siemens: " << xsize << "x" << ysize << " -> " << quadsize << "x" << quadsize << STD_endl;
         xsize=ysize=quadsize;
       }
-      int xoffset=(xsize-data.extent(3))/2;
-      int yoffset=(ysize-data.extent(2))/2;
+      int xoffset=(xsize-data.extent(readDim))/2;
+      int yoffset=(ysize-data.extent(phaseDim))/2;
       ODINLOG(odinlog,normalDebug) << "xsize/ysize/xoffset/yoffset=" << xsize << "/" << ysize << "/" << xoffset << "/" << yoffset << STD_endl;
 
       // adjust FOV in protocol to new matrix size
-      float FOVread= secureDivision(xsize,data.extent(3))*prot.geometry.get_FOV(readDirection);
-      float FOVphase=secureDivision(ysize,data.extent(2))*prot.geometry.get_FOV(phaseDirection);
+      float FOVread= secureDivision(xsize,data.extent(readDim))*prot.geometry.get_FOV(readDirection);
+      float FOVphase=secureDivision(ysize,data.extent(phaseDim))*prot.geometry.get_FOV(phaseDirection);
       prot.geometry.set_FOV(readDirection,  FOVread);
       prot.geometry.set_FOV(phaseDirection, FOVphase);
 
@@ -1008,9 +1053,7 @@ struct DicomFormat : public FileFormat {
       if(opts.dialect=="siemens") {
         // clip data for viewer on host
         u16bit thresh=std::numeric_limits<u16bit>::max()-10;
-        Array<u16bit,4> u16bitdata_copy(u16bitdata);
-        u16bitdata_copy=where(u16bitdata_copy>thresh, thresh, u16bitdata_copy);
-        u16bitdata=u16bitdata_copy;
+        clip_max(u16bitdata,thresh);
       }
 
       u16bit min_stored=min(u16bitdata);
@@ -1021,9 +1064,15 @@ struct DicomFormat : public FileFormat {
         bits_used=STD_max((unsigned int)1, (unsigned int)ceil(log(max_stored)/log(2)));
       }
       ODINLOG(odinlog,normalDebug) << "bits_used=" << bits_used << STD_endl;
-      if(check_status(func,"BitsAllocated",            dataset->putAndInsertString(DCM_BitsAllocated,       "16"))) return -1;
-      if(check_status(func,"BitsStored",               dataset->putAndInsertString(DCM_BitsStored,          itos(bits_used).c_str()))) return -1;
-      if(check_status(func,"HighBit",                  dataset->putAndInsertString(DCM_HighBit,             itos(bits_used-1).c_str()))) return -1;
+      if(check_status(func,"BitsAllocated", dataset->putAndInsertString(DCM_BitsAllocated, "16"))) return -1;
+      if(check_status(func,"BitsStored",    dataset->putAndInsertString(DCM_BitsStored, itos(bits_used).c_str()))) return -1;
+      if(check_status(func,"HighBit",       dataset->putAndInsertString(DCM_HighBit, itos(bits_used-1).c_str()))) return -1;
+
+      u16bit windowwidth=max_stored-min_stored;
+      u16bit windowcenter=min_stored+windowwidth/2;
+      ODINLOG(odinlog,normalDebug) << "windowwidth/windowcenter=" << windowwidth << "/" << windowcenter << STD_endl;
+      if(check_status(func,"WindowWidth",  dataset->putAndInsertString(DCM_WindowWidth, itos(windowwidth) .c_str()))) return -1;
+      if(check_status(func,"WindowCenter", dataset->putAndInsertString(DCM_WindowCenter, itos(windowcenter).c_str()))) return -1;
 
 
       // preserving (floating point) values
@@ -1040,15 +1089,16 @@ struct DicomFormat : public FileFormat {
 
       Data<u16bit,2> oneslice_padded(ysize,xsize);
 
-      for(int iframe=0; iframe<data.extent(0); iframe++) {
-        for(int iplane=0; iplane<data.extent(1); iplane++) {
+      for(int iframe=0; iframe<data.extent(timeDim); iframe++) {
+        for(int iplane=0; iplane<data.extent(sliceDim); iplane++) {
 
           // The instance UID and number, separate for each image
           if(check_status(func,"SOPInstanceUID",dataset->putAndInsertString(DCM_SOPInstanceUID, dcmGenerateUniqueIdentifier(uid, SITE_INSTANCE_UID_ROOT)))) return -1;
           if(check_status(func,"InstanceNumber",dataset->putAndInsertString(DCM_InstanceNumber, itos(index+1).c_str()))) return -1;
 
           // timestamp
-          double timestamp_s=double(iframe)*0.001*prot.seqpars.get_RepetitionTime();
+          ODINLOG(odinlog,normalDebug) << "acqstart/TR=" << prot.seqpars.get_AcquisitionStart() << "/" << prot.seqpars.get_RepetitionTime() << STD_endl;
+          double timestamp_s=0.001*(prot.seqpars.get_AcquisitionStart()+double(iframe)*prot.seqpars.get_RepetitionTime());
           int hours=int(timestamp_s)/3600;
           timestamp_s-=hours*3600;
           int minutes=int(timestamp_s)/60;
@@ -1056,8 +1106,8 @@ struct DicomFormat : public FileFormat {
           int seconds=int(timestamp_s);
           timestamp_s-=seconds;
           int fract=int(timestamp_s*1.0e6);
-          char timestr[100];
-          snprintf(timestr, 100, "%02i%02i%02i.%06i", hours, minutes, seconds, fract);
+          char timestr[1000];
+          snprintf(timestr, 1000, "%02i%02i%02i.%06i", hours, minutes, seconds, fract);
           if(check_status(func,"AcquisitionTime",dataset->putAndInsertString(DCM_AcquisitionTime, timestr))) return -1;
 
 
@@ -1070,7 +1120,7 @@ struct DicomFormat : public FileFormat {
           if(check_status(func,"SliceLocation",dataset->putAndInsertString(DCM_SliceLocation, ftos(slice_offset[iplane]).c_str()))) return -1;
 
           oneslice_padded=0;
-          oneslice_padded(Range(yoffset,yoffset+data.extent(2)-1), Range(xoffset,xoffset+data.extent(3)-1))=u16bitdata(iframe,iplane,all,all);
+          oneslice_padded(Range(yoffset,yoffset+data.extent(phaseDim)-1), Range(xoffset,xoffset+data.extent(readDim)-1))=u16bitdata(iframe,iplane,all,all);
 
           if(!insert_uint16_hack(dataset, DCM_SmallestImagePixelValue, min_stored)) return -1;
           if(!insert_uint16_hack(dataset, DCM_LargestImagePixelValue,  max_stored)) return -1;
@@ -1079,6 +1129,10 @@ struct DicomFormat : public FileFormat {
 
           STD_string basename(itos(index,10000000)); // Filenames with eight digits
           STD_string singlefname=dstdir+SEPARATOR_STR+basename; // only upper-case letters, no dot, max 8 chars allowed here
+          ODINLOG(odinlog,normalDebug) << "singlefname(" << index << ")=" << singlefname << STD_endl;
+#if OFFIS_DCMTK_VERSION_NUMBER > 354
+          if(check_status(func,"validateMetaInfo",fileformat.validateMetaInfo(EXS_LittleEndianExplicit, EWM_createNewMeta))) return -1; // avoid warnings about differences in SOPInstanceUID
+#endif
           if(check_status(func,"saveFile",fileformat.saveFile(singlefname.c_str(), EXS_LittleEndianExplicit))) return -1; // file must be stored before adding to DCOMDIR
 
           if(check_status(
