@@ -42,6 +42,10 @@ FileReadOpts::FileReadOpts() {
   fmap=false;
   fmap.set_cmdline_option("fmap").set_description("For reduced memory usage, keep filemapping after reading (raw) data, but writing into the array will result in a crash");
   append_member(fmap,"fmap");
+
+  framesplit=false;
+  framesplit.set_cmdline_option("framesplit").set_description("Force splitting frames with different acquisition times into separate protocol-data pairs");
+  append_member(framesplit,"framesplit");
 }
 
 //////////////////////////////////////////////////////////////
