@@ -2,7 +2,7 @@
                           filter_convolve.h  -  description
                              -------------------
     begin                : Thu Jun 13 2012
-    copyright            : (C) 2000-2015 by Thies Jochimsen
+    copyright            : (C) 2000-2019 by Thies Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -24,7 +24,7 @@
 class FilterConvolve : public FilterStep {
 
   LDRfilter kernel;
-  LDRfloat kerneldiameter;
+  LDRfloat kernelwidth;
 
   STD_string label() const {return "convolve";}
   STD_string description() const {return "Convolution in spatial dimensions";}
