@@ -1,5 +1,46 @@
 #include "filter_mask.h"
 #include "utils.h" // for TinyVector comparison
+#include "fitting.h" // for exponential fit
+
+
+
+struct ExponentialFunctionWithLinear : public ModelFunction {
+
+  fitpar A;
+  fitpar lambda;
+  fitpar M;
+  fitpar C;
+
+  // implementing virtual functions of ModelFunction
+  float evaluate_f(float x) const {
+    return A.val * exp (lambda.val * x) + M.val*x + C.val;
+  }
+
+  fvector evaluate_df(float x) const {
+    fvector result(numof_fitpars());
+    result[0]=exp (lambda.val * x);
+    result[1]=x * A.val * exp (lambda.val * x);
+    result[2]=x;
+    result[3]=1.0;
+    return result;
+  }
+
+  unsigned int numof_fitpars() const {return 4;}
+
+  fitpar& get_fitpar(unsigned int i) {
+    if(i==0) return A;
+    if(i==1) return lambda;
+    if(i==2) return M;
+    if(i==3) return C;
+    return dummy_fitpar;
+  }
+
+};
+
+
+
+///////////////////////////////////////////////////////////////////////////
+
 
 void FilterGenMask::init(){
   min.set_description("lower threshold");
@@ -9,29 +50,13 @@ void FilterGenMask::init(){
 }
 
 bool FilterGenMask::process(Data<float,4>& data, Protocol& prot) const {
-
-/*
-TinyVector<int,4> datashape=data.shape();
-  TinyVector<int,4> maskshape=data.shape();
-  maskshape(timeDim)=1;
-
-  Data<float,4> mask(maskshape); mask=1.0;
-  TinyVector<int,4> maskindex;
-  TinyVector<int,4> dataindex;
-  for(int i=0; i<mask.size(); i++) {
-    maskindex=mask.create_index(i);
-    dataindex=maskindex;
-    for(int irep=0; irep<datashape(timeDim); irep++) { // Condition must be met for all time steps
-      dataindex(timeDim)=irep;
-      float val=data(dataindex);
-      if(val<min || val>max) mask(maskindex)=0.0;
-    }
+  TinyVector<int,4> indexvec;
+  for(unsigned int i=0; i<data.numElements(); i++) {
+    indexvec=data.create_index(i);
+    float val=data(indexvec);
+    if(val>=min && val<=max) data(indexvec)=1.0;
+    else data(indexvec)=0.0;
   }
-
-  data.reference(mask);
-*/
-
-  data=where(Array<float,4>(data)>=min && Array<float,4>(data)<=max, float(1.0), float(0.0));
   return true;
 }
 
@@ -40,13 +65,25 @@ TinyVector<int,4> datashape=data.shape();
 
 void FilterAutoMask::init() {
 
-//  dump_histogram_fname.set_description("dump histogram");
-//  append_arg(dump_histogram_fname,"dump_histogram_fname");
+  skip=0;
+  skip.set_description("skip leftmost slots");
+  append_arg(skip,"skip");
+
+  dump_histogram_fname.set_description("dump histogram");
+  append_arg(dump_histogram_fname,"dump_histogram_fname");
+
+  dump_histogram_fit_fname.set_description("dump histogram fit");
+  append_arg(dump_histogram_fit_fname,"dump_histogram_fit_fname");
+
+
+
 }
 
 bool FilterAutoMask::process(Data<float,4>& data, Protocol& prot) const {
   Log<Filter> odinlog(c_label(),"process");
 
+  Range all=Range::all();
+
   int nslots=100;
 
   float maxval=max(data);
@@ -59,26 +96,98 @@ bool FilterAutoMask::process(Data<float,4>& data, Protocol& prot) const {
   // create histogram
   for(unsigned int i=0; i<data.size(); i++) {
     float val=data(data.create_index(i));
-    int slot=int(secureDivision(val,step));
-    ODINLOG(odinlog,normalDebug) << "val/slot=" << val << "/" << slot << STD_endl; 
-    if(slot>=0 && slot<nslots) hist(slot)++;
+    if(val!=0.0) { // omit synthetic values with zero intensity
+      int slot=int(secureDivision(val,step));
+      ODINLOG(odinlog,normalDebug) << "val/slot=" << val << "/" << slot << STD_endl; 
+      if(slot>=0 && slot<nslots) hist(slot)++;
+    }
   }
 
-//  ODINLOG(odinlog,infoLog) << "dump_histogram_fname=" << dump_histogram_fname << STD_endl; 
-//  if(dump_histogram_fname!="") hist.write_asc_file(dump_histogram_fname);
+  if(dump_histogram_fname!="") {
+    ODINLOG(odinlog,infoLog) << "dumping histogram to file " << dump_histogram_fname << STD_endl; 
+    hist.write_asc_file(dump_histogram_fname);
+  }
+
+  int slotstart=STD_max(maxIndex(hist)(0), int(skip)); // start at least at first maximum
+  ODINLOG(odinlog,normalDebug) << "slotstart=" << slotstart << STD_endl; 
 
 
-  // find first minimum
-  float thresh=0.0;
-  for(int islot=0; islot<(nslots-1); islot++) {
+
+  // 1st method: find first minimum
+  float thresh_min=0.0;
+  int islot;
+  for(islot=slotstart; islot<(nslots-1); islot++) {
     if(hist(islot+1)>hist(islot)) {
-      thresh=(islot+1)*step; // use one step after min for threshold
+      thresh_min=(islot+1)*step; // use one step after min for threshold
       break;
     }
   }
-  ODINLOG(odinlog,normalDebug) << "thresh=" << thresh << STD_endl; 
+  ODINLOG(odinlog,normalDebug) << "islot/thresh(min)=" << "/" << islot << "/" << thresh_min << STD_endl; 
 
-  data=where(Array<float,4>(data)>thresh, float(1.0), float(0.0));
+
+  // 2nd method: use exponential+linear fit of histogram
+  int nslots4fit=nslots-slotstart;
+  Data<float,1> hist4fit(nslots4fit);
+  hist4fit(all)=hist(Range(slotstart,nslots-1));
+
+  ExponentialFunctionWithLinear expfunc;
+  FunctionFitDerivative fitter;
+  if(!fitter.init(expfunc,nslots4fit)) return false;
+
+  Data<float,1> xvals(nslots4fit);
+  Data<float,1> ysigma(nslots4fit);
+  for(int islot=0; islot<nslots4fit; islot++) {
+    xvals(islot)=islot;
+    ysigma(islot)=1.0;
+  }
+
+  // starting values
+  expfunc.A.val=max(hist);
+  expfunc.lambda.val=-1;
+  expfunc.M.val=-1;
+  expfunc.C.val=0.0;
+
+  if(!fitter.fit(hist4fit, ysigma, xvals)) return false;
+
+  ODINLOG(odinlog,normalDebug) << "A=" << expfunc.A << STD_endl; 
+  ODINLOG(odinlog,normalDebug) << "lambda=" << expfunc.lambda << STD_endl; 
+  ODINLOG(odinlog,normalDebug) << "M=" << expfunc.M << STD_endl; 
+  ODINLOG(odinlog,normalDebug) << "C=" << expfunc.C << STD_endl; 
+
+
+  if(dump_histogram_fit_fname!="") {
+    ODINLOG(odinlog,infoLog) << "dumping histogram fit to file " << dump_histogram_fit_fname << STD_endl; 
+
+    hist4fit=expfunc.get_function(xvals); // overwrite real histogram by fit
+
+    Data<float,1> histfit(nslots); histfit=0.0;
+    for(int islot=0; islot<nslots4fit; islot++) histfit(slotstart+islot)=hist4fit(islot);
+
+    histfit.write_asc_file(dump_histogram_fit_fname);
+  }
+
+
+  for(islot=0; islot<nslots4fit; islot++) {
+    float expval=expfunc.A.val * exp (expfunc.lambda.val * islot);
+    float linval=expfunc.M.val*islot + expfunc.C.val;
+    ODINLOG(odinlog,normalDebug) << "expval/linval["<< islot << "]=" << expval << "/" << linval << STD_endl;
+    if(linval>=expval) break; // seth threshold where exponential falls below linear term
+  }
+  int threshslot_fit=slotstart+islot;
+  float thresh_fit=step*threshslot_fit;
+  ODINLOG(odinlog,normalDebug) << "threshslot_fit/thresh_fit=" << threshslot_fit << "/" << thresh_fit << STD_endl; 
+
+
+
+  float thresh=STD_min(thresh_min, thresh_fit); // combination of both methods
+
+
+  TinyVector<int,4> indexvec;
+  for(unsigned int i=0; i<data.numElements(); i++) {
+    indexvec=data.create_index(i);
+    if(data(indexvec)>thresh) data(indexvec)=1.0;
+    else data(indexvec)=0.0;
+  }
 
   return true;
 }
@@ -151,9 +260,6 @@ bool FilterSphereMask::process(Data<float,4>& data, Protocol& prot) const {
   Log<Filter> odinlog(c_label(),"process");
 
 
-  Range all=Range::all();
-
-
   svector toks=tokens(extract(pos, "(", ")", true),',');
   ODINLOG(odinlog,normalDebug) << "toks=" << toks.printbody() << STD_endl;
 
@@ -170,7 +276,6 @@ bool FilterSphereMask::process(Data<float,4>& data, Protocol& prot) const {
 
   Data<float,4> mask(maskshape); mask=0.0;
 
-  TinyVector<int,3> spatshape(shape(sliceDim), shape(phaseDim), shape(readDim));
 
   TinyVector<float,3> voxel_spacing;
   voxel_spacing(0)=FileFormat::voxel_extent(prot.geometry, sliceDirection, data.extent(sliceDim));
@@ -212,6 +317,8 @@ void FilterUseMask::init() {
 bool FilterUseMask::process(Data<float,4>& data, Protocol& prot) const {
   Log<Filter> odinlog(c_label(),"process");
 
+  Range all=Range::all();
+
   // Load external file
   Data<float,4> maskdata;
   if(maskdata.autoread(fname)<0) return false;
@@ -233,7 +340,7 @@ bool FilterUseMask::process(Data<float,4>& data, Protocol& prot) const {
   }
 
   data.resize(1,vals.size(),1,1);
-  data(0,Range::all(),0,0)=Data<float,1>(vals);
+  data(0,all,0,0)=Data<float,1>(vals);
 
   return true;
 }
