@@ -2,7 +2,7 @@
                           filter_mask.h  -  description
                              -------------------
     begin                : Wed Nov 5 2008
-    copyright            : (C) 2000-2015 by Thies Jochimsen
+    copyright            : (C) 2000-2019 by Thies Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -38,7 +38,9 @@ class FilterGenMask : public FilterStep {
 
 class FilterAutoMask : public FilterStep {
 
-//  LDRfileName dump_histogram_fname;
+  LDRint skip;
+  LDRfileName dump_histogram_fname;
+  LDRfileName dump_histogram_fit_fname;
 
   STD_string label() const {return "automask";}
   STD_string description() const {return "Create mask using automatic histogram-based threshold";}
