@@ -19,6 +19,11 @@ void FilterNaN::init(){
 
 bool FilterNaN::process(Data<float,4>& data, Protocol& prot)const{
   //replace all elements by replace where element does NOT equal itself (which is only true for NaN)
-  data=where(Array<float,4>(data) == Array<float,4>(data), Array<float,4>(data), (float)replace );
+  TinyVector<int,4> indexvec;
+  for(unsigned int i=0; i<data.numElements(); i++) {
+    indexvec=data.create_index(i);
+    float val=data(indexvec);
+    if(!(val == val)) data(indexvec)=replace;
+  }
   return true;
 }
