@@ -19,7 +19,7 @@
 */
 class FilterNaN : public FilterStep
 {
-  JDXfloat replace;
+  LDRfloat replace;
 
   STD_string label() const {return "noNaN";}
   STD_string description() const {return "Replaces every NaN by the given value";}
