@@ -2,7 +2,7 @@
                           filter_resize.h  -  description
                              -------------------
     begin                : Fri Feb 1 2008
-    copyright            : (C) 2000-2015 by Thies Jochimsen
+    copyright            : (C) 2000-2019 by Thies Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -49,7 +49,7 @@ class FilterResample : public FilterStep {
 class FilterIsotrop : public FilterStep {
   LDRfloat size;
   STD_string label() const {return "isotrop";}
-  STD_string description() const {return "make image voxels isotrop through interpolation (image geometry will not change)";}
+  STD_string description() const {return "make image voxels isotrop through interpolation (image geometry will not change), set to zero for minimum extent";}
   bool process(Data<float,4>& data, Protocol& prot) const;
   FilterStep*  allocate() const {return new FilterIsotrop();}
   void init();
