@@ -11,6 +11,7 @@
 #include "filter_lowpass.h"
 #include "filter_mask.h"
 #include "filter_merge.h"
+#include "filter_morph.h"
 #include "filter_nan.h"
 #include "filter_resize.h"
 #include "filter_rot.h"
@@ -58,6 +59,9 @@ void FilterStep::create_templates(STD_list<FilterStep*>& result) {
   result.push_back(new FilterSphereMask());
   result.push_back(new FilterUseMask());
 
+  result.push_back(new FilterMorph<erode>());
+  result.push_back(new FilterMorph<dilate>());
+
   result.push_back(new FilterNaN());
   result.push_back(new FilterRot());
 
