@@ -2,7 +2,7 @@
                           fitting.h  -  description
                              -------------------
     begin                : Fri Apr 6 2001
-    copyright            : (C) 2000-2015 by Thies Jochimsen & Michael von Mengershausen
+    copyright            : (C) 2000-2019 by Thies Jochimsen & Michael von Mengershausen
     email                : thies@jochimsen.de  mengers@cns.mpg.de
  ***************************************************************************/
 
@@ -333,7 +333,7 @@ struct PolynomialFunction {
            const Array<float,1>& ysigma,
            const Array<float,1>& xvals);
 
-  
+/*
   bool fit(const Array<float,1>& yvals,
            const Array<float,1>& ysigma){
   	firstIndex fi;
@@ -341,7 +341,8 @@ struct PolynomialFunction {
 	xvals=fi;
 	return fit(yvals,ysigma,xvals);
   };
-	
+*/
+
   bool fit(const Array<float,1>& yvals){
   	Array<float,1> ysigma(yvals.size());
 	ysigma=1.;
@@ -477,13 +478,14 @@ class DownhillSimplex {
   ~DownhillSimplex();
 
 /**
-  * Returns parameter values which minimize function
+  * Returns parameter values in 'result' which minimize attached 'function'
   * - starting_point: Starting from this initial point
   * - step_size: The size of the initial trial steps
   * - ftol:  Tolerannce
   * - nmax: Max number of iterations
+  * Returns true on success.
   */
-  fvector get_minimum_parameters(const fvector& starting_point, const fvector& step_size, unsigned int max_iterations=DEFAULT_MAX_ITER, double tolerance=DEFAULT_TOLERANCE);
+  bool get_minimum_parameters(fvector& result, const fvector& starting_point, const fvector& step_size, unsigned int max_iterations=DEFAULT_MAX_ITER, double tolerance=DEFAULT_TOLERANCE);
 
 
  private:
