@@ -2,7 +2,7 @@
                           mri_utils.h  -  description
                              -------------------
     begin                : Wed Feb 9 2005
-    copyright            : (C) 2000-2015 by Thies H. Jochimsen
+    copyright            : (C) 2000-2019 by Thies H. Jochimsen
     email                : 
  ***************************************************************************/
 
@@ -41,8 +41,8 @@ Data<float,1> unwrap_phase(const Data<float,1>& phase, int startindex=0);
 template<typename T>
 Array<T,1> matrix_product(const Array<T,2>& matrix, const Array<T,1>& vector) {
   Log<OdinData> odinlog("","matrix_product");
-  int nrows=matrix.extent()(0);
-  int ncols=matrix.extent()(1);
+  int nrows=matrix.extent(0);
+  int ncols=matrix.extent(1);
 
   Array<T,1> result(nrows);
   result=0;
@@ -71,8 +71,8 @@ Array<T,1> matrix_product(const Array<T,2>& matrix, const Array<T,1>& vector) {
 template<typename T>
 Array<T,2> matrix_product(const Array<T,2>& matrix1, const Array<T,2>& matrix2) {
   Log<OdinData> odinlog("","matrix_product");
-  int nrows=matrix1.extent()(0);
-  int ncols=matrix2.extent()(1);
+  int nrows=matrix1.extent(0);
+  int ncols=matrix2.extent(1);
   ODINLOG(odinlog,normalDebug) << "nrows/ncols=" << nrows << "/" << ncols << STD_endl;
 
   Array<T,2> result(nrows,ncols);
@@ -172,6 +172,20 @@ bool same_shape(const Array<T,N_rank>& a1, const Array<T,N_rank>& a2, const Tiny
   return true;
 }
 
+////////////////////////////////////////////////////////
+
+/**
+  * Checks whether multidimensional index 'index' is within the array with shape 'shape'
+  */
+template<int N_rank>
+bool on_grid(const TinyVector<int,3>& shape, const TinyVector<int,3>& index) {
+  for(int i=0; i<N_rank; i++) {
+    if(index(i)<0 || index(i)>=shape(i)) {
+      return false;
+    }
+  }
+  return true;
+}
 
 
 ////////////////////////////////////////////////////////
@@ -188,6 +202,32 @@ bool check_range(T& val, T min, T max) {
 }
 
 
+////////////////////////////////////////////////////////
+
+/**
+  * Clip all values above maximum value
+  */
+template<typename T, int N_rank>
+void clip_max(Data<T,N_rank>& data, T val) {
+  TinyVector<int,N_rank> indexvec;
+  for(unsigned int i=0; i<data.numElements(); i++) {
+    indexvec=data.create_index(i);
+    if(data(indexvec)>val) data(indexvec)=val;
+  }
+}
+
+/**
+  * Clip all values below minimum value
+  */
+template<typename T, int N_rank>
+void clip_min(Data<T,N_rank>& data, T val) {
+  TinyVector<int,N_rank> indexvec;
+  for(unsigned int i=0; i<data.numElements(); i++) {
+    indexvec=data.create_index(i);
+    if(data(indexvec)<val) data(indexvec)=val;
+  }
+}
+
 
 
 /** @}
