@@ -503,8 +503,10 @@ Geometry& Geometry::set_orientation_and_offset(const dvector& readvec, const dve
 
   double rr_scalarproduct=(rvec*rvec_inplane).sum();
   double rp_scalarproduct=(rvec*pvec_inplane).sum();
-  if(rr_scalarproduct>1.0) rr_scalarproduct=1.0; if(rr_scalarproduct<-1.0) rr_scalarproduct=-1.0;
-  if(rp_scalarproduct>1.0) rp_scalarproduct=1.0; if(rp_scalarproduct<-1.0) rp_scalarproduct=-1.0;
+  if(rr_scalarproduct>1.0)  rr_scalarproduct=1.0;
+  if(rr_scalarproduct<-1.0) rr_scalarproduct=-1.0;
+  if(rp_scalarproduct>1.0)  rp_scalarproduct=1.0;
+  if(rp_scalarproduct<-1.0) rp_scalarproduct=-1.0;
   ODINLOG(odinlog,normalDebug) << "rr/rp_scalarproduct=" << rr_scalarproduct << "/" << rp_scalarproduct << STD_endl;
 
   inplaneAngle=180.0/PII*atan2(-rp_scalarproduct,rr_scalarproduct); // clock-wise angle
