@@ -170,8 +170,8 @@ double Nuclei::get_nuc_freq(const STD_string& nucName,float B0) const {
 }
 
 
-JDXenum Nuclei::get_nuc_enum() const {
-  JDXenum result;
+LDRenum Nuclei::get_nuc_enum() const {
+  LDRenum result;
   for(STD_list<Nucleus>::const_iterator it=nuclist.begin();it!=nuclist.end();++it) {
     result.add_item(it->first);
   }
@@ -181,7 +181,7 @@ JDXenum Nuclei::get_nuc_enum() const {
 /////////////////////////////////////////////////////////////////////////////
 
 
-System::System(const STD_string& object_label) : JcampDxBlock(object_label) {
+System::System(const STD_string& object_label) : LDRblock(object_label) {
   Log<Para> odinlog(this, "System(...)");
 
 
@@ -214,6 +214,9 @@ System::System(const STD_string& object_label) : JcampDxBlock(object_label) {
   transmit_coil_name="Unknown";
   transmit_coil_name.set_cmdline_option("tcname").set_description("Name of transmit coil");
 
+  receive_coil_name="Unknown";
+  receive_coil_name.set_cmdline_option("rcname").set_description("Name of receive coil");
+
   inter_grad_delay=0.0;
   inter_grad_delay.set_unit(ODIN_TIME_UNIT).set_description("Minimum delay between gradient objects");
 
@@ -243,23 +246,20 @@ System::System(const STD_string& object_label) : JcampDxBlock(object_label) {
 
 
 System& System::operator = (const System& s) {
-  JcampDxBlock::operator = (s);
+  LDRblock::operator = (s);
 
   System::append_all_members();
 
-  // copy only visible members of JcampDxBlock
+  // copy only visible members of LDRblock
   copy_ldr_vals(s);
 
 
-
-
   // preserve parmode and filemode which varies across platforms
-
-
   grad_shift         .set_filemode(s.grad_shift         .get_filemode()).set_parmode(s.grad_shift         .get_parmode());
   inter_grad_delay   .set_filemode(s.inter_grad_delay   .get_filemode()).set_parmode(s.inter_grad_delay   .get_parmode());
   reference_gain     .set_filemode(s.reference_gain     .get_filemode()).set_parmode(s.reference_gain     .get_parmode());
   transmit_coil_name .set_filemode(s.transmit_coil_name .get_filemode()).set_parmode(s.transmit_coil_name .get_parmode());
+  receive_coil_name  .set_filemode(s.receive_coil_name  .get_filemode()).set_parmode(s.receive_coil_name  .get_parmode());
   delay_rastertime   .set_filemode(s.delay_rastertime   .get_filemode()).set_parmode(s.delay_rastertime   .get_parmode());
   rf_rastertime      .set_filemode(s.rf_rastertime      .get_filemode()).set_parmode(s.rf_rastertime      .get_parmode());
   grad_rastertime    .set_filemode(s.grad_rastertime    .get_filemode()).set_parmode(s.grad_rastertime    .get_parmode());
@@ -294,7 +294,10 @@ System& System::set_transmit_coil_name(const STD_string& tcname) {
   return *this;
 }
 
-
+System& System::set_receive_coil_name(const STD_string& rcname) {
+  receive_coil_name=rcname;
+  return *this;
+}
 
 float System::get_grad_switch_time(float graddiff) const {
   return ( secureDivision(fabs(graddiff),max_slew_rate) + get_inter_grad_delay() );
@@ -319,7 +322,9 @@ double System::get_gamma(const STD_string& nucName) const {
 System& System::set_scandir(const STD_string& dir) {
   Log<Para> odinlog(this,"set_scandir");
 #ifndef NO_FILEHANDLING
-  if(!checkdir(dir.c_str())) ODINLOG(odinlog,errorLog) << "scan directory " << dir << " does not exist" << STD_endl;
+  if(!checkdir(dir.c_str())) {
+    ODINLOG(odinlog,errorLog) << "scan directory " << dir << " does not exist" << STD_endl;
+  }
 #endif
   scandir=dir;
   return *this;
@@ -333,7 +338,7 @@ double System::get_nuc_freq(const STD_string& nucName) const {
 }
 
 
-JDXenum System::get_nuc_enum() const {return nuc.get_nuc_enum();}
+LDRenum System::get_nuc_enum() const {return nuc.get_nuc_enum();}
 
 
 double System::get_rastertime(objCategory cat) const {
@@ -376,7 +381,7 @@ bool System::allowed_grad_freq(double freq, double& low, double& upp) const {
 
 
 
-int System::load(const STD_string &filename) {
+int System::load(const STD_string &filename, const LDRserBase& serializer) {
   Log<Para> odinlog(this,"load");
   ODINLOG(odinlog,errorLog) << "called" << STD_endl;
   return -1;
@@ -391,6 +396,7 @@ int System::append_all_members() {
   append_member(B0,"MagneticFieldStrength");
   append_member(reference_gain,"ReferenceGain");
   append_member(transmit_coil_name,"TransmitCoilName");
+  append_member(receive_coil_name,"ReceiveCoilName");
   append_member(inter_grad_delay,"InterGradientSwitchingDelay");
   append_member(delay_rastertime,"DelayRasterTime");
   append_member(grad_rastertime,"GradientRasterTime");
@@ -449,8 +455,8 @@ void SystemInterface::set_current_pf(odinPlatform pf) {
 }
 
 
-template class SingletonHandler<JDXint,false>;
-SingletonHandler<JDXint,false> SystemInterface::current_pf;
+template class SingletonHandler<LDRint,false>;
+SingletonHandler<LDRint,false> SystemInterface::current_pf;
 
 template class SingletonHandler<System,false>;
 SingletonHandler<System,false>* SystemInterface::systemInfo_platform=0;
