@@ -32,7 +32,7 @@ class BladeGrid {
     ComplexData<4> operator () (const ComplexData<4>& src, const dvector& angles) const;
 
   private:
-    Data<float,2> filtermask_center;
+    ComplexData<2> filtermask_center;
     TinyVector<float,2> dstextent;
     TinyVector<float,2> dstshape;
     TinyVector<float,2> kmax;
