@@ -6,6 +6,30 @@
 #include "fieldmap.h" // for posted_fmap_str
 
 
+//////////////////////////////////////////////////////////////////////////////////////
+
+
+class RecoThread : public Thread, public Labeled {
+
+ public:
+  RecoThread() {}
+  bool init(const STD_string& label, RecoController& controller) {
+    set_label(label);
+    pcontroller=&controller;
+    return true;
+  }
+
+ private:
+
+  void run() {
+    while(pcontroller->feed_pipeline()) {}
+    pcontroller->incr_waiting_threads("Waiting for end of reco");
+  }
+
+  RecoController* pcontroller;
+};
+
+//////////////////////////////////////////////////////////////////////////////////////
 
 
 RecoController::RecoController(LDRblock& parblock) : input(0), pipeline(0), factory(0), pmeter(display) {
@@ -166,26 +190,32 @@ TinyVector<float,3> RecoController::kspace_extent() const {
 }
 
 
-bool RecoController::inquire_data(const STD_string& label, RecoData& data) {
+bool RecoController::inquire_data(const RecoStep& caller, const STD_string& label, RecoData& data) {
   Log<Reco> odinlog("RecoController","inquire_data");
 
-  if(!status) return false; // Return immediately if an error occured, i.e. do not wait for any data in this case
+  if(!status) {
+    blackboard.release_waiting_threads();
+    return false; // Return immediately if an error occured, i.e. do not wait for any data in this case
+  }
 
-  ODINLOG(odinlog,normalDebug) << "Requested " << label << "(" << data.coord().print() << ")" << STD_endl;
+  ODINLOG(odinlog,normalDebug) << "Requested " << label << "(" << data.coord().print() << ") by " << caller.label() << STD_endl;
 
-  if(blackboard.inquire(label,data)) {
+  if(blackboard.inquire(label,data,false)) {
     ODINLOG(odinlog,normalDebug) << "Returning " << label << "(" << data.coord().print() << ")" << STD_endl;
-    return true; // 1st shot without feeding pipeline or signalling waiting state
+    return true; // 1st successful try without feeding pipeline with other data or signalling waiting state
   }
   ODINLOG(odinlog,normalDebug) <<  label << "(" << data.coord().print() << ") not ready" << STD_endl;
 
+  thread_depth_mutex.lock();
   int depth=thread_depth[Thread::self()];
+  thread_depth_mutex.unlock();
+
   if(depth<maxrecursion) { // avoid massive recursion
 
     ODINLOG(odinlog,normalDebug) << "Recursing in depth=" << depth << STD_endl;
 
     while(feed_pipeline()) { // Continue feeding pipeline until no data is available
-      if(blackboard.inquire(label,data)) {
+      if(blackboard.inquire(label,data,false)) {
         ODINLOG(odinlog,normalDebug) << "Returning " << label << "(" << data.coord().print() << ")" << STD_endl;
         return true; // Return immediately if inquired data becomes available
       }
@@ -193,28 +223,41 @@ bool RecoController::inquire_data(const STD_string& label, RecoData& data) {
     ODINLOG(odinlog,normalDebug) << "Pipeline empty" << STD_endl;
   }
 
-  incr_waiting_threads("Waiting for "+label+"("+data.coord().print()+")");
+/*
+  if(depth>=maxrecursion) { // start new thread before we go to waiting state
+    RecoThread extrathread;
+    extrathread.init("extra",*this);
+    extrathread.start(8*1024*1024);
+    extrathread.wait();
+  }
+*/
 
-  while(!blackboard.inquire(label,data,true)) { // block while waiting
-    int nwaiting=numof_waiting_threads();
-    ODINLOG(odinlog,normalDebug) << "nwaiting=" << nwaiting << STD_endl;
-    if(int(numof_waiting_threads()) >= jobs) { // signal an error if all threads are waiting for input
-      ODINLOG(odinlog,errorLog) << "Out of input data while waiting for " << label << "(" << data.coord().print() << ")" << STD_endl;
+  incr_waiting_threads("Step "+caller.label()+" waiting for "+label+"("+data.coord().print()+"), thread_depth="+itos(depth));
 
-      MutexLock lock(waiting_mutex);
-
-      // store snapshot of states of waiting threads for later error report
-      waiting_error="Waiting threads:\n";
+  int nwaiting=numof_waiting_threads();
+  ODINLOG(odinlog,normalDebug) << "nwaiting=" << nwaiting << STD_endl;
+  if(nwaiting >= jobs) { // signal an error if all threads are waiting for input
+    ODINLOG(odinlog,normalDebug) << "All threads waiting for data, this thread is waiting for " << label << "(" << data.coord().print() << ")" << STD_endl;
+    waiting_mutex.lock();
+    if(waiting_error=="") { // store snapshot of states of waiting threads at first occurence of error for later report
+      waiting_error="All threads waiting:\n";
       for(WaitingMap::const_iterator it=waiting.begin(); it!=waiting.end(); ++it) {
         waiting_error+="job"+itos(it->first)+": "+it->second+"\n";
       }
-
-      return false;
     }
-//    ODINLOG(odinlog,normalDebug) <<  "sleeping while waiting for " << label << STD_endl;
-//    sleep_ms(10); // Avoid tight inifinite loop, give other threads CPU time to process their input
+    waiting_mutex.unlock();
+    blackboard.release_waiting_threads();
+    return false;
   }
-  ODINLOG(odinlog,normalDebug) << "blocked inquire successful" << STD_endl;
+
+
+  if(!blackboard.inquire(label,data,true)) { // block while waiting
+    ODINLOG(odinlog,errorLog) << "Blocked wait for (" << data.coord().print() << ") failed" << STD_endl;
+    blackboard.release_waiting_threads();
+    return false;
+  }
+
+  ODINLOG(odinlog,normalDebug) << "Blocked inquire successful" << STD_endl;
 
   decr_waiting_threads();
 
@@ -919,30 +962,6 @@ bool RecoController::init(RecoReaderInterface* reader, LDRblock& opts, int argc,
   return true;
 }
 
-//////////////////////////////////////////////////////////////////////////////////////
-
-
-class RecoThread : public Thread, public Labeled {
-
- public:
-  RecoThread() {}
-  bool init(const STD_string& label, RecoController& controller) {
-    set_label(label);
-    pcontroller=&controller;
-    return true;
-  }
-
- private:
-
-  void run() {
-    while(pcontroller->feed_pipeline()) {}
-    pcontroller->incr_waiting_threads("Waiting for end of reco");
-  }
-
-  RecoController* pcontroller;
-};
-
-//////////////////////////////////////////////////////////////////////////////////////
 
 bool RecoController::dump_raw() const {
   Log<Reco> odinlog("RecoController","dump_raw");
@@ -987,7 +1006,9 @@ bool RecoController::feed_pipeline() {
   if(!fetchresult) return false;
 
 
+  thread_depth_mutex.lock();
   thread_depth[Thread::self()]++;
+  thread_depth_mutex.unlock();
 
   // Final preparations for pipeline
   for(int idim=0; idim<n_recoDims; idim++) coord.index[idim].set_numof(numof_cache[idim]);
@@ -1004,7 +1025,9 @@ bool RecoController::feed_pipeline() {
   if(!result) status=false;
   pmeter.increase_counter();
 
+  thread_depth_mutex.lock();
   thread_depth[Thread::self()]--;
+  thread_depth_mutex.unlock();
 
   return result;
 }
@@ -1021,13 +1044,22 @@ bool RecoController::execute_pipeline() {
   status=true;
 
   for(int i=0; i<jobs; i++) threads[i].init("job"+itos(i),*this);
-  for(int i=0; i<jobs; i++) threads[i].start(8*1024*1024); // 8 MB stack size
+  for(int i=0; i<jobs; i++) threads[i].start(ODINRECO_THREAD_STACKSIZE);
   for(int i=0; i<jobs; i++) threads[i].wait();
 
   delete[] threads;
 
+  // for debugging
   if(waiting_error!="") {
     ODINLOG(odinlog,errorLog) <<  waiting_error;
+    inputmutex.lock();
+    RecoCoord dummycoord;
+    ComplexData<1> dummyadc;
+    if(input->fetch(dummycoord, dummyadc)) {
+      ODINLOG(odinlog,errorLog) <<  "Input not completely processed" << STD_endl;
+    }
+    inputmutex.unlock();
+
   }
 
   return status;
@@ -1055,7 +1087,7 @@ bool RecoController::prepare_pipeline() {
     ComplexData<3>& fmapdata=rdfmap.data(Rank<3>());
 
     if(phase3dmode) {
-      ODINLOG(odinlog,infoLog) << "Posting 3D fieldmap"<< STD_endl;
+      ODINLOG(odinlog,infoLog) << "Posting 3D fieldmap" << STD_endl;
 
       fmapdata.reference(cfmap);
       post_data(posted_fmap_str, rdfmap);
