@@ -21,6 +21,8 @@ RecoData& RecoData::free(int dim) {
   if(dim==4) data4.free();
   if(dim==5) data5.free();
   if(dim==6) data6.free();
+  if(dim==7) data7.free();
+  if(dim==8) data8.free();
   return *this;
 }
 
@@ -31,6 +33,8 @@ RecoData& RecoData::operator = (const RecoData& rd) {
   data4.reference(rd.data4.copy());
   data5.reference(rd.data5.copy());
   data6.reference(rd.data6.copy());
+  data7.reference(rd.data7.copy());
+  data8.reference(rd.data8.copy());
   return copy_meta(rd);
 }
 
