@@ -327,7 +327,7 @@ bool RecoGrappa<interpolDim,orthoDim,interpolIndex,orthoIndex>::process(RecoData
 
   ODINLOG(odinlog,normalDebug) << "Requesting weights for " << rd.coord().print() << STD_endl;
   RecoData rdweights(rd.coord());
-  if(!controller.inquire_data(grappa_postlabel(interpolDim), rdweights)) return false;
+  if(!controller.inquire_data(*this, grappa_postlabel(interpolDim), rdweights)) return false;
   ODINLOG(odinlog,normalDebug) << "Retrieved weights with " << rdweights.coord().print() << STD_endl;
 
   const ComplexData<5>& weights=rdweights.data(Rank<5>());
