@@ -81,7 +81,7 @@ bool RecoReaderOdin::init(const STD_string& input_filename) {
   // get weighting factors for different channels
   nChannels_cache=coords[0].channels; // assume the same for all ADCs
   channelFactors=recoInfo.get_ChannelScales();
-  if(channelFactors.extent(firstDim)<int(nChannels_cache)) {
+  if(channelFactors.extent(0)<int(nChannels_cache)) {
     ODINLOG(odinlog,warningLog) << "number of channels larger than number of channel scales, will use uniform scale" << STD_endl;
     channelFactors.resize(nChannels_cache);
     channelFactors=1.0;
@@ -330,6 +330,8 @@ bool RecoReaderOdin::read_block(T2 dummy, ComplexData<2>& block) {
 bool RecoReaderOdin::fetch(RecoCoord& coord, ComplexData<1>& adc) {
   Log<Reco> odinlog("RecoReaderOdin","fetch");
 
+  ODINLOG(odinlog,normalDebug) << "index/chancount=" << index  << "/" << chancount << STD_endl;
+
   if(index>=get_coords().size()) return false;
 
   coord=get_coords()[index];
@@ -339,8 +341,11 @@ bool RecoReaderOdin::fetch(RecoCoord& coord, ComplexData<1>& adc) {
 
     kcoord_cache=recoInfo.get_kSpaceCoord(ri_index);
 
+    ODINLOG(odinlog,normalDebug) << "channels/adcSize=" << kcoord_cache.channels << "/" << kcoord_cache.adcSize << STD_endl;
     rawdata.resize(kcoord_cache.channels,kcoord_cache.adcSize);
+
     bool readresult=false;
+    ODINLOG(odinlog,normalDebug) << "dataformat=" << dataformat << STD_endl;
     if(dataformat==TypeTraits::type2label((s16bit)0)) readresult=read_block((s16bit)0, rawdata);
     if(dataformat==TypeTraits::type2label((s32bit)0)) readresult=read_block((s32bit)0, rawdata);
     if(dataformat==TypeTraits::type2label((float)0))  readresult=read_block((float)0,  rawdata);
