@@ -8,6 +8,7 @@
 #include "conjphase.h"
 #include "controller.h"
 #include "adc.h"
+#include "debug.h"
 #include "dump.h"
 #include "dti.h"
 #include "driftcorr.h"
@@ -122,6 +123,7 @@ void RecoStep::create_templates(STD_list<RecoStep*>& result) {
   result.push_back(new RecoCycleRot());
   result.push_back(new RecoDeapodize<1>());
   result.push_back(new RecoDeapodize<2>());
+  result.push_back(new RecoDebug());
   result.push_back(new RecoDump());
   result.push_back(new RecoDTI());
   result.push_back(new RecoDriftCalc());
