@@ -9,8 +9,6 @@ STD_string RecoStore::default_format() {
   result="nii";
 #elif defined DICOMSUPPORT
   result="dcm";
-#elif defined VISTASUPPORT
-  result="v";
 #endif
   return result;
 }
