@@ -33,8 +33,6 @@ STD_vector<TinyVector<int,3> > neighb_indices(int radius_pixels) {
 bool RecoSwi::process(RecoData& rd, RecoController& controller) {
   Log<Reco> odinlog(c_label(),"process");
 
-  Range all=Range::all();
-
   ComplexData<3>& data=rd.data(Rank<3>());
   TinyVector<int,3> shape=data.shape();
 
@@ -46,7 +44,7 @@ bool RecoSwi::process(RecoData& rd, RecoController& controller) {
 
   // Create linear mask for valid pixels
   Data<char,1> mask(magn.size()); mask=1;
-  for(int i=0; i<magn.size(); i++) {
+  for(unsigned int i=0; i<magn.size(); i++) {
     TinyVector<int,3> index=magn.create_index(i);
     for(int j=0; j<3; j++) {
       if(index(j)<pixelradius)            mask(i)=0;
@@ -76,7 +74,7 @@ bool RecoSwi::process(RecoData& rd, RecoController& controller) {
 
   TinyVector<float,3> cogvec;
 
-  for(int i=0; i<magn.size(); i++) {
+  for(unsigned int i=0; i<magn.size(); i++) {
     if(mask(i)) {
       TinyVector<int,3> index=magn.create_index(i);
 
