@@ -668,7 +668,7 @@ SeqAcqEPI::SeqAcqEPI(const STD_string& object_label)
 
 
 
-RecoValList SeqAcqEPI::get_recovallist(unsigned int reptimes, JDXkSpaceCoords& coords) const {
+RecoValList SeqAcqEPI::get_recovallist(unsigned int reptimes, LDRkSpaceCoords& coords) const {
   Log<Seq> odinlog(this,"get_recovallist");
 
   int nTEs=2*echo_pairs_cache;
@@ -686,7 +686,9 @@ RecoValList SeqAcqEPI::get_recovallist(unsigned int reptimes, JDXkSpaceCoords& c
   RecoValList result;
 
   int isegment=dephobjs->phasesegdephgrad.get_current_index();
-  if(templtype_cache==no_template) ODINLOG(odinlog,normalDebug) << "isegment=" << isegment << STD_endl;
+  if(templtype_cache==no_template) {
+    ODINLOG(odinlog,normalDebug) << "isegment=" << isegment << STD_endl;
+  }
 
   for(int iecho=0; iecho<nechoes; iecho++) {
     kSpaceCoord kcoord(kcoord_base);
