@@ -98,8 +98,8 @@ class CatchSegFaultContext : public StaticHandler<CatchSegFaultContext> {
 
 
   static void destroy_static() {
-    if(label) delete label; label=0;
-    if(lastmsg) delete lastmsg; lastmsg=0;
+    if(label) {delete label; label=0;}
+    if(lastmsg) {delete lastmsg; lastmsg=0;}
   }
 
  private:
