@@ -61,32 +61,32 @@ void SeqSimMagsi::common_init() {
 
 
 void SeqSimMagsi::outdate_simcache() {
-  if(time_intervals_cache) delete[] time_intervals_cache; time_intervals_cache=0;
-  if(xpos_cache) delete[] xpos_cache; xpos_cache=0;
-  if(ypos_cache) delete[] ypos_cache; ypos_cache=0;
-  if(zpos_cache) delete[] zpos_cache; zpos_cache=0;
-  if(freqoffset_cache) delete[] freqoffset_cache; freqoffset_cache=0;
-  if(ppm_cache) delete[] ppm_cache; ppm_cache=0;
-  if(spin_density_cache) delete[] spin_density_cache; spin_density_cache=0;
-  if(B1map_transm_cache) delete[] B1map_transm_cache; B1map_transm_cache=0;
+  if(time_intervals_cache) {delete[] time_intervals_cache; time_intervals_cache=0;}
+  if(xpos_cache) {delete[] xpos_cache; xpos_cache=0;}
+  if(ypos_cache) {delete[] ypos_cache; ypos_cache=0;}
+  if(zpos_cache) {delete[] zpos_cache; zpos_cache=0;}
+  if(freqoffset_cache) {delete[] freqoffset_cache; freqoffset_cache=0;}
+  if(ppm_cache) {delete[] ppm_cache; ppm_cache=0;}
+  if(spin_density_cache) {delete[] spin_density_cache; spin_density_cache=0;}
+  if(B1map_transm_cache) {delete[] B1map_transm_cache; B1map_transm_cache=0;}
   if(B1map_receiv_cache) {
     for(unsigned int ichan=0; ichan<num_rec_channel_cache; ichan++) delete[] B1map_receiv_cache[ichan];
     delete[] B1map_receiv_cache; B1map_receiv_cache=0;
   }
-  if(Dcoeff_cache) delete[] Dcoeff_cache; Dcoeff_cache=0;
+  if(Dcoeff_cache) {delete[] Dcoeff_cache; Dcoeff_cache=0;}
   sim_diffusion=false;
 
-  if(r1_cache) delete[] r1_cache; r1_cache=0;
-  if(r2_cache) delete[] r2_cache; r2_cache=0;
-  if(has_relax_cache) delete[] has_relax_cache; has_relax_cache=0;
+  if(r1_cache) {delete[] r1_cache; r1_cache=0;}
+  if(r2_cache) {delete[] r2_cache; r2_cache=0;}
+  if(has_relax_cache) {delete[] has_relax_cache; has_relax_cache=0;}
 
   // intra-voxel magn gradients
   for(unsigned int k=0; k<4; k++) {
-    if(dMx[k]) delete[] dMx[k]; dMx[k]=0;
-    if(dMy[k]) delete[] dMy[k]; dMy[k]=0;
-    if(dMz[k]) delete[] dMz[k]; dMz[k]=0;
+    if(dMx[k]) {delete[] dMx[k]; dMx[k]=0;}
+    if(dMy[k]) {delete[] dMy[k]; dMy[k]=0;}
+    if(dMz[k]) {delete[] dMz[k]; dMz[k]=0;}
     if(k<3) {
-      if(dppm[k]) delete[] dppm[k]; dppm[k]=0;
+      if(dppm[k]) {delete[] dppm[k]; dppm[k]=0;}
     }
   }
 
@@ -1002,11 +1002,11 @@ void SeqSimMonteCarlo::common_init() {
 }
 
 void SeqSimMonteCarlo::clear_cache() {
-  if(Dcoeff_cache) delete[] Dcoeff_cache; Dcoeff_cache=0;
-  if(ppmMap_cache) delete[] ppmMap_cache; ppmMap_cache=0;
-  if(R1map_cache) delete[] R1map_cache; R1map_cache=0;
-  if(R2map_cache) delete[] R2map_cache; R2map_cache=0;
-  if(spinDensity_cache) delete[] spinDensity_cache; spinDensity_cache=0;
+  if(Dcoeff_cache) {delete[] Dcoeff_cache; Dcoeff_cache=0;}
+  if(ppmMap_cache) {delete[] ppmMap_cache; ppmMap_cache=0;}
+  if(R1map_cache) {delete[] R1map_cache; R1map_cache=0;}
+  if(R2map_cache) {delete[] R2map_cache; R2map_cache=0;}
+  if(spinDensity_cache) {delete[] spinDensity_cache; spinDensity_cache=0;}
 }
 
 
