@@ -12,16 +12,16 @@
 
 
 struct SeqFieldMapPars {
-  JcampDxBlock parblock;
-  JDXint NumOfEchoes;
-  JDXfloat Resolution;
-  JDXdouble T1Ernst;
-  JDXint DummyCycles;
-  JDXint ReadSize;
-  JDXint PhaseSize;
-  JDXint SliceSize;
-  JDXdouble FlashFlipAngle;
-  JDXdouble ExtraDelay;
+  LDRblock parblock;
+  LDRint NumOfEchoes;
+  LDRfloat Resolution;
+  LDRdouble T1Ernst;
+  LDRint DummyCycles;
+  LDRint ReadSize;
+  LDRint PhaseSize;
+  LDRint SliceSize;
+  LDRdouble FlashFlipAngle;
+  LDRdouble ExtraDelay;
 };
 
 struct SeqFieldMapObjects {
@@ -220,7 +220,7 @@ void SeqFieldMap::build_seq(double sweepwidth, float os_factor, const SeqObjList
 }
 
 
-JcampDxBlock& SeqFieldMap::get_parblock() {
+LDRblock& SeqFieldMap::get_parblock() {
   alloc_data(get_label());
   return pars->parblock;
 }
