@@ -45,7 +45,7 @@ unsigned int SeqTrigger::event(eventContext& context) const {
   if(context.action==seqRun) {
     triggdriver->event(context,startelapsed);
   }
-  if(context.event_progmeter) context.event_progmeter->increase_counter();
+  context.increase_progmeter();
   return 1;
 }
 
@@ -90,7 +90,7 @@ unsigned int SeqHalt::event(eventContext& context) const {
   if(context.action==seqRun) {
     triggdriver->event(context,startelapsed);
   }
-  if(context.event_progmeter) context.event_progmeter->increase_counter();
+  context.increase_progmeter();
   return 1;
 }
 
@@ -127,7 +127,7 @@ unsigned int SeqSnapshot::event(eventContext& context) const {
   if(context.action==seqRun) {
     triggdriver->event(context,startelapsed);
   }
-  if(context.event_progmeter) context.event_progmeter->increase_counter();
+  context.increase_progmeter();
   return 1;
 }
 
@@ -156,7 +156,7 @@ unsigned int SeqMagnReset::event(eventContext& context) const {
   if(context.action==seqRun) {
     triggdriver->event(context,startelapsed);
   }
-  if(context.event_progmeter) context.event_progmeter->increase_counter();
+  context.increase_progmeter();
   return 1;
 }
 
