@@ -35,7 +35,7 @@ SeqVector::~SeqVector() {
 SeqVector& SeqVector::operator = (const SeqVector& sv) {
   SeqClass::operator = (sv);
   indexvec=sv.indexvec;
-  if(reordvec) delete reordvec; reordvec=0;
+  if(reordvec) {delete reordvec; reordvec=0;}
   if(sv.reordvec) reordvec=new SeqReorderVector(this,sv.reordvec);
   return *this;
 }
