@@ -2,7 +2,7 @@
                           seqplot_standalone.h  -  description
                              -------------------
     begin                : Fri Jul 23 2004
-    copyright            : (C) 2000-2015 by Thies H. Jochimsen
+    copyright            : (C) 2000-2019 by Thies H. Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -54,8 +54,9 @@ struct SeqSimulationOpts : public LDRblock {
   LDRint SimThreads;
 
   LDRbool IntraVoxelMagnGrads;
+#ifdef VTKSUPPORT
   LDRbool MagnMonitor;
-
+#endif
   LDRdouble ReceiverNoise;
 
   LDRfileName TransmitterCoil;
@@ -407,7 +408,13 @@ class SeqPlotData : public STD_list<SeqPlotFrame>, public virtual SeqPlotDataAbs
 
   void set_coilsdir(const STD_string& coilsdir) const;
 
-  bool monitor_simulation() const {return sim_opts.MagnMonitor;}
+  bool monitor_simulation() const {
+#ifdef VTKSUPPORT
+    return sim_opts.MagnMonitor;
+#else
+    return false;
+#endif
+  }
 
   bool simulate(const STD_string& fidfile, const STD_string& samplefile, ProgressMeter* progmeter, SeqSimFeedbackAbstract* feedback) const;
 
