@@ -8,11 +8,11 @@ class METHOD_CLASS : public SeqMethod {
 
 private:
 
-  JDXint   NumOfEchoes;
-  JDXfloat PulseDur;
-  JDXint   NumOfSatPulses;
+  LDRint   NumOfEchoes;
+  LDRfloat PulseDur;
+  LDRint   NumOfSatPulses;
 
-  JDXdoubleArr TEs;
+  LDRdoubleArr TEs;
 
   // sequence objects which are the elementary objects
   // to build the EPI sequence
