@@ -8,18 +8,18 @@ class METHOD_CLASS : public SeqMethod {
 
 private:
 
-  JDXint   NumOfEchoes;
-  JDXbool  SEAcquisition;
-  JDXint   Blades;
-  JDXint   Shots;
-  JDXfloat PulseDur;
-  JDXbool  RampSampling;
-  JDXbool  FatSaturation;
-  JDXbool  fMRITrigger;
-  JDXfloat FWbVal;
-  JDXbool  FieldMap;
+  LDRint   NumOfEchoes;
+  LDRbool  SEAcquisition;
+  LDRint   Blades;
+  LDRint   Shots;
+  LDRfloat PulseDur;
+  LDRbool  RampSampling;
+  LDRbool  FatSaturation;
+  LDRbool  fMRITrigger;
+  LDRfloat FWbVal;
+  LDRbool  FieldMap;
 
-  JDXdoubleArr TEs;
+  LDRdoubleArr TEs;
 
   // sequence objects which are the elementary objects
   // to build the EPI sequence
