@@ -16,9 +16,6 @@ STD_string LogMessage::str(unsigned int maxwidth, bool include_comp) const {
   if(len>MAX_LOG_STRINGSIZE) funcCrop=func.substr(len-MAX_LOG_STRINGSIZE, MAX_LOG_STRINGSIZE);
   else funcCrop=func;
 
-  const char* member_separator="";
-  if(obj.length()) member_separator=".";
-
   STD_string line;
 
   if(include_comp) line+=comp+STD_string(MAX_COMPONENT_SIZE-comp.length(),' ')+"|";
