@@ -401,12 +401,15 @@ int load(STD_string& str, const STD_string& filename) {
 #ifndef NO_FILEHANDLING
 
   LONGEST_INT file_size=filesize(filename.c_str());
-  if(file_size<=0) {
-    ODINLOG(odinlog,warningLog) << "file >" << filename << "< not found or is empty" << STD_endl;
+  if(file_size<0) {
+    ODINLOG(odinlog,warningLog) << "file >" << filename << "< not found" << STD_endl;
     return -1;
   }
-
-  FILE* file_ptr=FOPEN(filename.c_str(),modestring(readMode));
+  if(file_size==0) {
+    str="";
+    return 0;
+  }
+  FILE* file_ptr=ODIN_FOPEN(filename.c_str(),modestring(readMode));
   if(file_ptr==NULL) {
     ODINLOG(odinlog,errorLog) << "unable to open file >" << filename << "< - " << lasterr() << STD_endl;
     return -1;
@@ -431,7 +434,7 @@ int write(const STD_string& str, const STD_string& filename, fopenMode mode) {
   Log<StringComp> odinlog("","write");
 #ifndef NO_FILEHANDLING
 
-  FILE* file_ptr=FOPEN(filename.c_str(),modestring(mode));
+  FILE* file_ptr=ODIN_FOPEN(filename.c_str(),modestring(mode));
 
   if(file_ptr==NULL) {
     ODINLOG(odinlog,errorLog) << "unable to create file:  >" << filename << "< - " << lasterr() << STD_endl;
