@@ -2,7 +2,7 @@
                           tjtools.h  -  description
                              -------------------
     begin                : Thu Jul 13 2000
-    copyright            : (C) 2000-2015 by Thies Jochimsen
+    copyright            : (C) 2000-2019 by Thies Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -344,6 +344,13 @@ int hasHelpOption(int argc, char *argv[]);
   */
 const char* helpUsage();
 
+/**
+  *
+  * Returns general information about the ODIN package/configuration
+  */
+const char* configInfo();
+
+
 #endif
 
 
