@@ -10,7 +10,7 @@ unsigned int TypeTraits::typesize(const STD_string& typelabel) {
   if(typelabel==TypeTraits::type2label((float)0))  return sizeof(float);
   if(typelabel==TypeTraits::type2label((double)0)) return sizeof(double);
   if(typelabel==TypeTraits::type2label((STD_complex)0)) return sizeof(STD_complex);
-  if(typelabel==TypeTraits::type2label((STD_string)0)) return sizeof(STD_string);
+//  if(typelabel==TypeTraits::type2label(STD_string(""))) return sizeof(STD_string); // string does not have fixed size
   return 0;
 }
 
