@@ -681,7 +681,7 @@ int tjvector<T>::load(const STD_string& fname) {
 
   T* buff=new T[nelements];
 
-  if(fread(buff,sizeof(T),nelements,file_ptr)!=nelements) {
+  if((LONGEST_INT)fread(buff,sizeof(T),nelements,file_ptr)!=nelements) {
     ODINLOG(odinlog,errorLog) << "unable to read data from file >" << fname << "<, " << lasterr() << STD_endl;
   } else {
     (*this)=tjvector<T>(buff,nelements);
@@ -713,7 +713,7 @@ int tjvector<T>::write(const STD_string& fname, fopenMode mode, LONGEST_INT nele
     return(-1);
   }
 
-  if(fwrite(c_array(),sizeof(T),nelements,file_ptr)!=nelements) {
+  if((LONGEST_INT)fwrite(c_array(),sizeof(T),nelements,file_ptr)!=nelements) {
     ODINLOG(odinlog,errorLog) << "unable to write data to file >" << fname << "<, " << lasterr() << STD_endl;
   }
   if(file_ptr!=NULL) fclose(file_ptr);
@@ -725,6 +725,7 @@ int tjvector<T>::write(const STD_string& fname, fopenMode mode, LONGEST_INT nele
 /////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
 
+// template instantiations
 template class tjvector<float>;
 template class tjvector<double>;
 template class tjvector<int>;
